Package: BP4RNAseq
Type: Package
Title: A babysitter's package for reproducible RNA-seq analysis
Version: 1.23.0
Authors@R: c(person(given = "Shanwen",
            family = "Sun",
            role = c("cre", "aut"),
            email = "sunshanwen@gmail.com"),
            person(given = "Lei",
                   family = "Xu",
                   role = "aut"),
            person(given = "Quan",
                   family = "Zou",
                   role = "aut"))
Description: An automated pipe for reproducible RNA-seq analysis with the minimal efforts from researchers. The package can process bulk RNA-seq data and single-cell RNA-seq data. You can only provide the taxa name and the accession id of RNA-seq data deposited in the National Center for Biotechnology Information (NCBI). After a cup of tea or longer, you will get formated gene expression data as gene count and transcript count based on both alignment-based and alignment-free workflows.
License: GPL-2
Encoding: UTF-8
Imports: dplyr, fastqcr, stringr, tidyr, stats, utils, magrittr,
        reticulate
Depends: R (>= 4.0.0)
SystemRequirements: UNIX, SRA Toolkit=2.10.3, Entrez Direct=13.3,
        FastQC=v0.11.9, Cutadapt=2.10, datasets, SAMtools=1.9,
        HISAT2=2.2.0, StringTie=2.1.1, Salmon=1.2.1
RoxygenNote: 7.1.1
biocViews: GeneExpressionWorkflow
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/BP4RNAseq
git_branch: devel
git_last_commit: c76cfd2
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-05
NeedsCompilation: no
Packaged: 2026-05-05 17:05:04 UTC; biocbuild
Author: Shanwen Sun [cre, aut],
  Lei Xu [aut],
  Quan Zou [aut]
Maintainer: Shanwen Sun <sunshanwen@gmail.com>
