# Generated by roxygen2: do not edit by hand

export(adapter_trim)
export(align_based_quan)
export(align_free_quan)
export(average)
export(check_dep)
export(down2quan)
export(down_Ref)
export(fastq2quan)
export(qc_test)
export(quality_trim)
export(scRNA_quan)
export(sra2fastq)
export(sra_download)
import(stringr)
importFrom(magrittr,'%>%')
